@@ -3,7 +3,7 @@
 #' Asylum seekers in receipt of support at end of period, by nationality,
 #' support type, and UK region.
 #'
-#' @format A data frame with 60,699 rows and 7 variables:
+#' @format A data frame with 64,527 rows and 7 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Nationality}{Nationality of people receiving support}
@@ -40,7 +40,7 @@
 #' Asylum applications awaiting an initial decision or further review, by
 #' nationality and applicant type.
 #'
-#' @format A data frame with 31,485 rows and 7 variables:
+#' @format A data frame with 32,085 rows and 7 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Nationality}{Nationality of people awaiting a decision}
@@ -59,7 +59,7 @@
 #' Asylum applications raised, by nationality, age, sex, UASC, applicant type,
 #' and location of application.
 #'
-#' @format A data frame with 66,526 rows and 11 variables:
+#' @format A data frame with 68,133 rows and 11 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -83,7 +83,7 @@
 #' in the UK, by nationality, age, sex, applicant type, and UASC (unaccompanied
 #' asylum-seeking children).
 #'
-#' @format A data frame with 105,372 rows and 14 variables:
+#' @format A data frame with 107,070 rows and 14 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -184,7 +184,7 @@
 #'
 #' Age disputes raised and outcomes of age disputes.
 #'
-#' @format A data frame with 3,591 rows and 8 variables:
+#' @format A data frame with 3,740 rows and 8 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -245,7 +245,7 @@
 #' Family reunion visas granted to family members of refugees, by nationality,
 #' sex and age.
 #'
-#' @format A data frame with 8,036 rows and 8 variables:
+#' @format A data frame with 8,160 rows and 8 variables:
 #' \describe{
 #'   \item{Date}{The period in which the Family Reunion visa was granted}
 #'   \item{Year}{Year}
@@ -264,7 +264,7 @@
 #'
 #' Refugees resettled by resettlement scheme and local authority.
 #'
-#' @format A data frame with 2,614 rows and 8 variables:
+#' @format A data frame with 2,655 rows and 8 variables:
 #' \describe{
 #'   \item{Date}{The period in which the refugee arrived in the UK}
 #'   \item{Year}{Year}
@@ -283,7 +283,7 @@
 #'
 #' Asylum seekers in receipt of section 95 support by local authority.
 #'
-#' @format A data frame with 16,471 rows and 8 variables:
+#' @format A data frame with 17,554 rows and 9 variables:
 #' \describe{
 #'   \item{Date}{The date at which the number of people in receipt of support refers to}
 #'   \item{Year}{Year}
@@ -337,7 +337,7 @@
 #' Number of individuals transferred between local authorities under the
 #' National Transfer Scheme for unaccompanied asylum seeking children.
 #'
-#' @format A data frame with 11,680 rows and 9 variables:
+#' @format A data frame with 28 rows and 9 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -357,7 +357,7 @@
 #'
 #' Applications for Support Section 4 and Section 95.
 #'
-#' @format A data frame with 53 rows and 5 variables:
+#' @format A data frame with 54 rows and 5 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -373,7 +373,7 @@
 #'
 #' Travel documents, applications raised and despatched.
 #'
-#' @format A data frame with 52 rows and 5 variables:
+#' @format A data frame with 53 rows and 5 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -423,7 +423,7 @@
 #'
 #' The Decision Quality percentage of Decisions Sampled.
 #'
-#' @format A data frame with 15 rows and 5 variables:
+#' @format A data frame with 16 rows and 5 variables:
 #' \describe{
 #'   \item{Financial Year}{Financial year}
 #'   \item{Assurance}{First line or second line assurance}
@@ -439,7 +439,7 @@
 #'
 #' Percentage of Asylum applications processed within 6 months
 #'
-#' @format A data frame with 34 rows and 16 variables:
+#' @format A data frame with 35 rows and 16 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -467,7 +467,7 @@
 #' Age of Asylum Operations Initial Decision Work In Progress - applications
 #' made from 1st Oct 2006.
 #'
-#' @format A data frame with 26 rows and 8 variables:
+#' @format A data frame with 27 rows and 8 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -486,7 +486,7 @@
 #'
 #' Asylum work in progress.
 #'
-#' @format A data frame with 12 rows and 17 variables:
+#' @format A data frame with 13 rows and 17 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -514,7 +514,7 @@
 #'
 #' Breakdown of Asylum costs and productivity.
 #'
-#' @format A data frame with 12 rows and 12 variables:
+#' @format A data frame with 13 rows and 12 variables:
 #' \describe{
 #'   \item{Financial Year}{Financial year}
 #'   \item{Total Asylum Costs}{The costs of managing an asylum operations claim include a) costs associated with deciding a case (screening clients, interviews and issuing a decision), b) managing any related appeal, c) the cost of all asylum operations support (S4, S95 & S98) d) detention costs where detention has been used and e) enforcement costs (escorting and assisted voluntary returns). Also included are the costs of department staff and buildings and the proportionate costs of the Home Office building and managerial costs}
@@ -541,7 +541,7 @@
 #' relating to NRPF can be found here:
 #' https://homeofficemedia.blog.gov.uk/2020/05/05/no-recourse-to-public-funds-nrpf/
 #'
-#' @format A data frame with 23 rows and 10 variables:
+#' @format A data frame with 24 rows and 10 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -566,7 +566,7 @@
 #' relating to NRPF can be found here:
 #' https://homeofficemedia.blog.gov.uk/2020/05/05/no-recourse-to-public-funds-nrpf/
 #'
-#' @format A data frame with 23 rows and 12 variables:
+#' @format A data frame with 24 rows and 12 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -593,7 +593,7 @@
 #' relating to NRPF can be found here:
 #' https://homeofficemedia.blog.gov.uk/2020/05/05/no-recourse-to-public-funds-nrpf/
 #'
-#' @format A data frame with 159 rows and 24 variables:
+#' @format A data frame with 162 rows and 25 variables:
 #' \describe{
 #'   \item{Nationality}{Nationality}
 #'   \item{2017 Q3}{2017 Q3}
@@ -619,6 +619,7 @@
 #'   \item{2022 Q3}{2022 Q3}
 #'   \item{2022 Q4}{2022 Q4}
 #'   \item{2023 Q1}{2023 Q1}
+#'   \item{2023 Q2}{2023 Q2}
 #'   ...
 #' }
 #' @source \url{https://www.gov.uk/government/collections/migration-transparency-data#uk-visas-and-immigration}
@@ -632,7 +633,7 @@
 #' relating to NRPF can be found here:
 #' https://homeofficemedia.blog.gov.uk/2020/05/05/no-recourse-to-public-funds-nrpf/
 #'
-#' @format A data frame with 23 rows and 6 variables:
+#' @format A data frame with 24 rows and 6 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -650,7 +651,7 @@
 #' Initial decisions on asylum applications certified under Section 94, by
 #' nationality
 #'
-#' @format A data frame with 2,166 rows and 10 variables:
+#' @format A data frame with 2,191 rows and 10 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -672,7 +673,7 @@
 #' Number of entries into immigration detention by nationality, age, sex and
 #' initial place of detention.
 #'
-#' @format A data frame with 71,106 rows and 9 variables:
+#' @format A data frame with 71,915 rows and 9 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -693,7 +694,7 @@
 #' Number of people in immigration detention at the end of each quarter by
 #' nationality, age, sex, current place of detention and length of detention.
 #'
-#' @format A data frame with 77,628 rows and 10 variables:
+#' @format A data frame with 78,140 rows and 10 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -715,7 +716,7 @@
 #' Number of occurrences of people leaving detention by nationality, age, sex,
 #' reason for leaving detention and length of detention
 #'
-#' @format A data frame with 102,116 rows and 10 variables:
+#' @format A data frame with 104,181 rows and 10 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -737,7 +738,7 @@
 #' Number of returns from the UK, by nationality, age, sex, type of return and
 #' return destination group
 #'
-#' @format A data frame with 230,342 rows and 11 variables:
+#' @format A data frame with 232,451 rows and 11 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -759,7 +760,7 @@
 #'
 #' Number of returns from the UK, by type of return and country of destination
 #'
-#' @format A data frame with 42,042 rows and 8 variables:
+#' @format A data frame with 42,480 rows and 8 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -779,7 +780,7 @@
 #' Number of foreign national offender returns from the UK, by nationality and
 #' return destination group.
 #'
-#' @format A data frame with 6,297 rows and 7 variables:
+#' @format A data frame with 6,376 rows and 7 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -797,7 +798,7 @@
 #'
 #' Number of foreign national offender returns from the UK, by destination.
 #'
-#' @format A data frame with 4,474 rows and 6 variables:
+#' @format A data frame with 4,540 rows and 6 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -810,9 +811,37 @@
 #' @source \url{https://www.gov.uk/government/statistical-data-sets/returns-and-detention-datasets}
 "returns_offenders_by_destination"
 
+#' Returns from the UK, by nationality, type of return, and asylum/non-asylum
+#'
+#' @format A data frame with 22 rows and 5 variables:
+#' \describe{
+#'   \item{Category}{Asylum-related or non-asylum-related return?}
+#'   \item{Nationality}{Nationality of people being returned}
+#'   \item{Enforced returns}{Number of enforced returns}
+#'   \item{Voluntary returns}{Number of voluntary returns}
+#'   \item{Refused entry at port and subsequently departed}{Number refused entry at port and subsequently departed}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/statistical-data-sets/returns-and-detention-datasets}
+"returns_asylum"
+
+#' Returns from the UK, by nationality, type of return, and asylum/non-asylum
+#'
+#' @format A data frame with 26 rows and 5 variables:
+#' \describe{
+#'   \item{Date of return}{Date of return}
+#'   \item{Category}{Asylum-related or non-asylum-related return?}
+#'   \item{Enforced returns}{Number of enforced returns}
+#'   \item{Voluntary returns}{Number of voluntary returns}
+#'   \item{Refused entry at port and subsequently departed}{Number refused entry at port and subsequently departed}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/statistical-data-sets/returns-and-detention-datasets}
+"returns_asylum_longitudinal"
+
 #' People entering, leaving and in detention by asylum and non-asylum
 #'
-#' People entering, leaving and in detention by asylum and non-asylum, 2010 to 2022.
+#' People entering, leaving and in detention by asylum and non-asylum.
 #'
 #' @format A data frame with 13 rows and 10 variables:
 #' \describe{
@@ -825,7 +854,7 @@
 #'   \item{Leaving detention Non-asylum}{Leaving detention Non-asylum}
 #'   \item{In detention (at end of period)}{In detention (at end of period)}
 #'   \item{In detention Asylum}{In detention Asylum}
-#'   \item{In detentionNon-asylum}{In detention Non-asylum}
+#'   \item{In detention Non-asylum}{In detention Non-asylum}
 #'   ...
 #' }
 #' @source \url{https://www.gov.uk/government/statistical-data-sets/immigration-system-statistics-data-tables-year-ending-march-2023#detention}
@@ -850,14 +879,15 @@
 "children_entering_detention"
 
 #' Deaths of persons detained under Immigration Act Powers and absconds from
-#' detention, 2017 to 2021
+#' detention, 2017 to 2022
 #'
-#' @format A data frame with 5 rows and 4 variables:
+#' @format A data frame with 6 rows and 5 variables:
 #' \describe{
 #'   \item{Year}{Year}
 #'   \item{Deaths of persons detained under Immigration Powers}{Deaths of persons detained under Immigration Powers}
 #'   \item{Of which occurred in the detention estate}{Of which occurred in the detention estate}
-#'   \item{Absconds from detention}{Absconds from detention}
+#'   \item{Escapes from detention centres}{Escapes from detention centres}
+#'   \item{Absconds from escort}{Absconds from escort}
 #'   ...
 #' }
 #' @source \url{https://www.gov.uk/government/statistical-data-sets/immigration-system-statistics-data-tables-year-ending-december-2022#detention}
@@ -885,7 +915,7 @@
 #' Number of detected attempts to enter the UK irregularly by method of entry,
 #' nationality, region, sex and age group.
 #'
-#' @format A data frame with 9,114 rows and 9 variables:
+#' @format A data frame with 9,658 rows and 9 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -906,7 +936,7 @@
 #' Number of asylum applications from small boat arrivals by asylum application,
 #' nationality, region, applicant type, sex and age group.
 #'
-#' @format A data frame with 3,252 rows and 10 variables:
+#' @format A data frame with 3,969 rows and 11 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -915,6 +945,7 @@
 #'   \item{Nationality}{Nationality}
 #'   \item{Region}{Region}
 #'   \item{Applicant type}{Main applicant or dependant}
+#'   \item{UASC}{Unaccompanied asylum-seeking children?}
 #'   \item{Sex}{Sex}
 #'   \item{Age Group}{Age Group}
 #'   \item{Applications}{Number of applications}
@@ -929,7 +960,7 @@
 #' nationality, region, asylum case outcome, asylum case outcome group,
 #' applicant type, sex and age group.
 #'
-#' @format A data frame with 4,365 rows and 11 variables:
+#' @format A data frame with 5,380 rows and 12 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -939,6 +970,7 @@
 #'   \item{Asylum Case Outcome}{Specific outcome of the asylum case}
 #'   \item{Asylum Case Outcome Group}{Type of outcome}
 #'   \item{Applicant type}{Main applicant or dependant}
+#'   \item{UASC}{Unaccompanied asylum-seeking children?}
 #'   \item{Sex}{Sex}
 #'   \item{Age Group}{Age Group}
 #'   \item{Decisions}{Number of decisions}
@@ -952,7 +984,7 @@
 #' Number of NRM referrals from small boat arrivals by NRM referral,
 #' nationality, region, sex and age group.
 #'
-#' @format A data frame with 2,890 rows and 9 variables:
+#' @format A data frame with 3,334 rows and 9 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -973,7 +1005,7 @@
 #' Outcomes of NRM referrals from small boat arrivals by nationality, region,
 #' sex, age group, NRM case outcome and NRM case outcome group.
 #'
-#' @format A data frame with 2,321 rows and 10 variables:
+#' @format A data frame with 2,768 rows and 10 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -995,7 +1027,7 @@
 #' Grant rate is the proportion of initial decisions which resulted in a grant
 #' of protection or other leave.
 #'
-#' @format A data frame with 9,867 rows and 8 variables:
+#' @format A data frame with 9,965 rows and 8 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -1015,7 +1047,7 @@
 #' Grant rate is the proportion of initial decisions which resulted in a grant
 #' of protection or other leave.
 #'
-#' @format A data frame with 3,281 rows and 6 variables:
+#' @format A data frame with 3,295 rows and 6 variables:
 #' \describe{
 #'   \item{Year}{Year}
 #'   \item{Nationality}{Nationality}
@@ -1064,7 +1096,7 @@
 #' the total number of asylum-related returns of asylum seekers (beyond those in
 #' the inadmissibility process), see the Returns summary table Ret_05.
 #'
-#' @format A data frame with 45 rows and 5 variables:
+#' @format A data frame with 50 rows and 5 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Quarter}{Quarter}
@@ -1099,7 +1131,7 @@
 
 #' Number of pregnant women detained in the immigration detention estate
 #'
-#' @format A data frame with 27 rows and 4 variables:
+#' @format A data frame with 28 rows and 4 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -1112,7 +1144,7 @@
 
 #' Average cost per day to hold an individual in immigration detention
 #'
-#' @format A data frame with 41 rows and 4 variables:
+#' @format A data frame with 42 rows and 4 variables:
 #' \describe{
 #'   \item{Date}{Date}
 #'   \item{Year}{Year}
@@ -1122,3 +1154,532 @@
 #' }
 #' @source \url{https://www.gov.uk/government/collections/migration-transparency-data#immigration-enforcement}
 "detention_cost_per_day"
+
+#' NRM referrals by quarter by age at exploitation and location of exploitation
+#'
+#' @format A data frame with 855 rows and 5 variables:
+#' \describe{
+#'   \item{Year}{Year}
+#'   \item{Quarter}{Quarter}
+#'   \item{Age at exploitation}{Age at exploitation}
+#'   \item{Location of exploitation}{Location of exploitation}
+#'   \item{NRM referrals}{Number of NRM referrals}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_longitudinal"
+
+#' NRM referrals - Q2 2022
+#'
+#' @format A data frame with 44,420 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_2022_q2"
+
+#' NRM referrals from Government first responders - Q2 2022
+#'
+#' @format A data frame with 26,010 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_govt_2022_q2"
+
+#' NRM referrals from NGO and third sector first responders - Q2 2022
+#'
+#' @format A data frame with 9,765 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_ngo_2022_q2"
+
+#' NRM referrals from Police first responders - Q2 2022
+#'
+#' @format A data frame with 87,042 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_police_2022_q2"
+
+#' NRM referrals from Local Authority first responders - Q2 2022
+#'
+#' @format A data frame with 8,556 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_la_2022_q2"
+
+#' NRM referrals - Q3 2022
+#'
+#' @format A data frame with 51,520 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_2022_q3"
+
+#' NRM referrals from Government first responders - Q3 2022
+#'
+#' @format A data frame with 25,553 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_govt_2022_q3"
+
+#' NRM referrals from NGO and third sector first responders - Q3 2022
+#'
+#' @format A data frame with 14,756 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_ngo_2022_q3"
+
+#' NRM referrals from Police first responders - Q3 2022
+#'
+#' @format A data frame with 93,696 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_police_2022_q3"
+
+#' NRM referrals from Local Authority first responders - Q3 2022
+#'
+#' @format A data frame with 11,115 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_la_2022_q3"
+
+#' NRM referrals - Q4 2022
+#'
+#' @format A data frame with 48,966 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_2022_q4"
+
+#' NRM referrals from Government first responders - Q4 2022
+#'
+#' @format A data frame with 25,000 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_govt_2022_q4"
+
+#' NRM referrals from NGO and third sector first responders - Q4 2022
+#'
+#' @format A data frame with 12,992 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_ngo_2022_q4"
+
+#' NRM referrals from Police first responders - Q4 2022
+#'
+#' @format A data frame with 96,768 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_police_2022_q4"
+
+#' NRM referrals from Local Authority first responders - Q4 2022
+#'
+#' @format A data frame with 10,878 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_la_2022_q4"
+
+#' NRM referrals - Q1 2023
+#'
+#' @format A data frame with 49,104 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_2023_q1"
+
+#' NRM referrals from Government first responders - Q1 2023
+#'
+#' @format A data frame with 23,712 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_govt_2023_q1"
+
+#' NRM referrals from NGO and third sector first responders - Q1 2023
+#'
+#' @format A data frame with 11,286 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_ngo_2023_q1"
+
+#' NRM referrals from Police first responders - Q1 2023
+#'
+#' @format A data frame with 98,700 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_police_2023_q1"
+
+#' NRM referrals from Local Authority first responders - Q1 2023
+#'
+#' @format A data frame with 14,012 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_la_2023_q1"
+
+#' NRM referrals - Q2 2023
+#'
+#' @format A data frame with 49,752 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_2023_q2"
+
+#' NRM referrals from Government first responders - Q2 2023
+#'
+#' @format A data frame with 27,195 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_govt_2023_q2"
+
+#' NRM referrals from NGO and third sector first responders - Q2 2023
+#'
+#' @format A data frame with 11,820 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_ngo_2023_q2"
+
+#' NRM referrals from Police first responders - Q2 2023
+#'
+#' @format A data frame with 93,411 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_police_2023_q2"
+
+#' NRM referrals from Local Authority first responders - Q2 2023
+#'
+#' @format A data frame with 10,640 rows and 7 variables:
+#' \describe{
+#'   \item{First responder type}{First responder type}
+#'   \item{First responder}{First responder}
+#'   \item{Exploitation type}{Labour, domestic, sexual etc. exploitation}
+#'   \item{Age at exploitation}{Age group}
+#'   \item{Gender}{Gender/sex}
+#'   \item{Nationality}{Nationality}
+#'   \item{People}{Number of people referred to NRM}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_referrals_la_2023_q2"
+
+#' Referrals received via the Duty to Notify process in Q2 2022, by nationality
+#'
+#' @format A data frame with 90 rows and 2 variables:
+#' \describe{
+#'   \item{Nationality}{Nationality}
+#'   \item{Total}{Number of referrals via duty to notify}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_duty_to_notify_2022_q2"
+
+#' Referrals received via the Duty to Notify process in Q3 2022, by nationality
+#'
+#' @format A data frame with 99 rows and 2 variables:
+#' \describe{
+#'   \item{Nationality}{Nationality}
+#'   \item{Total}{Number of referrals via duty to notify}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_duty_to_notify_2022_q3"
+
+#' Referrals received via the Duty to Notify process in Q4 2022, by nationality
+#'
+#' @format A data frame with 98 rows and 2 variables:
+#' \describe{
+#'   \item{Nationality}{Nationality}
+#'   \item{Total}{Number of referrals via duty to notify}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_duty_to_notify_2022_q4"
+
+#' Referrals received via the Duty to Notify process in Q1 2023, by nationality
+#'
+#' @format A data frame with 97 rows and 2 variables:
+#' \describe{
+#'   \item{Nationality}{Nationality}
+#'   \item{Total}{Number of referrals via duty to notify}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_duty_to_notify_2023_q1"
+
+#' Referrals received via the Duty to Notify process in Q2 2023, by nationality
+#'
+#' @format A data frame with 94 rows and 2 variables:
+#' \describe{
+#'   \item{Nationality}{Nationality}
+#'   \item{Total}{Number of referrals via duty to notify}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_duty_to_notify_2023_q2"
+
+#' Referrals received via the Duty to Notify process, by quarter
+#'
+#' @format A data frame with 40 rows and 3 variables:
+#' \describe{
+#'   \item{Year}{Year}
+#'   \item{Quarter}{Quarter}
+#'   \item{Total}{Number of referrals via duty to notify}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_duty_to_notify_longitudinal"
+
+#' NRM reasonable grounds decisions
+#'
+#' NRM reasonable grounds decisions made by both competent authorities by
+#' quarter, outcome and age at exploitation.
+#'
+#' @format A data frame with 48 rows and 12 variables:
+#' \describe{
+#'   \item{Year}{Year}
+#'   \item{Quarter}{Quarter}
+#'   \item{Adult (18 or over) - Negative reasonable grounds}{Adult (18 or over) - Negative reasonable grounds}
+#'   \item{Adult (18 or over) - Positive reasonable grounds}{Adult (18 or over) - Positive reasonable grounds}
+#'   \item{Adult (18 or over) - Total}{Adult (18 or over) - Total}
+#'   \item{Child (17 or under) - Negative reasonable grounds}{Child (17 or under) - Negative reasonable grounds}
+#'   \item{Child (17 or under) - Positive reasonable grounds}{Child (17 or under) - Positive reasonable grounds}
+#'   \item{Child (17 or under) - Total}{Child (17 or under) - Total}
+#'   \item{Age not specified or unknown - Negative reasonable grounds}{Age not specified or unknown - Negative reasonable grounds}
+#'   \item{Age not specified or unknown - Positive reasonable grounds}{Age not specified or unknown - Positive reasonable grounds}
+#'   \item{Age not specified or unknown - Total}{Age not specified or unknown - Total}
+#'   \item{Total}{Total decisions}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_reasonable_grounds"
+
+#' NRM conclusive grounds decisions
+#'
+#' NRM conclusive grounds decisions made by both competent authorities by
+#' quarter, outcome and age at exploitation.
+#'
+#' @format A data frame with 48 rows and 12 variables:
+#' \describe{
+#'   \item{Year}{Year}
+#'   \item{Quarter}{Quarter}
+#'   \item{Adult (18 or over) - Negative conclusive grounds}{Adult (18 or over) - Negative conclusive grounds}
+#'   \item{Adult (18 or over) - Positive conclusive grounds}{Adult (18 or over) - Positive conclusive grounds}
+#'   \item{Adult (18 or over) - Total}{Adult (18 or over) - Total}
+#'   \item{Child (17 or under) - Negative conclusive grounds}{Child (17 or under) - Negative conclusive grounds}
+#'   \item{Child (17 or under) - Positive conclusive grounds}{Child (17 or under) - Positive conclusive grounds}
+#'   \item{Child (17 or under) - Total}{Child (17 or under) - Total}
+#'   \item{Age not specified or unknown - Negative conclusive grounds}{Age not specified or unknown - Negative conclusive grounds}
+#'   \item{Age not specified or unknown - Positive conclusive grounds}{Age not specified or unknown - Positive conclusive grounds}
+#'   \item{Age not specified or unknown - Total}{Age not specified or unknown - Total}
+#'   \item{Total}{Total decisions}
+#'   ...
+#' }
+#' @source \url{https://www.gov.uk/government/collections/national-referral-mechanism-statistics}
+"nrm_conclusive_grounds"
